[![Build Status](https://travis-ci.org/pwnbus/electrician.svg?branch=master)](https://travis-ci.org/pwnbus/electrician)
[![Test Coverage](https://api.codeclimate.com/v1/badges/c176e6ca4029974b9d5c/test_coverage)](https://codeclimate.com/github/pwnbus/electrician/test_coverage)

# Electrician
